@@ -103,7 +103,7 @@ function(x, y=NULL, data=d, rows=NULL,
   if (!is.null(dfs)) {
     if (df.name %in% dfs) {  # tibble to df
       if (any(grepl("tbl", class(data), fixed=TRUE))) {
-        data <- data.frame(data, stringsAsFactors=TRUE)
+        data <- data.frame(data, stringsAsFactors=FALSE)
       }
     }
   }
@@ -188,9 +188,9 @@ function(x, y=NULL, data=d, rows=NULL,
     }
 
     # or do a tabulation to get value of y
-    if (fill.name == "(count)") {
+    if (substr(fill.name, 1, 6) == "(count") {
       xtb <- table(x.call)
-      fill <- .getColC(xtb)
+      fill <- .getColC(xtb, fill.name=fill.name)
     }  # end .count 
   }  # end !fill.miss
 
