@@ -1,5 +1,6 @@
 .plt.legend <-
-function(colnms, horiz, color, fill, shape, col.bg, usr, lab.cex=0.8) {
+function(colnms, horiz, color, fill, shape, col.bg, usr, lab.cex=0.8,
+         pt.size=1.25, legend.title=NULL) {
 
   par(xpd=NA) 
   
@@ -8,7 +9,7 @@ function(colnms, horiz, color, fill, shape, col.bg, usr, lab.cex=0.8) {
 
   text.cex <- ifelse(is.null(getOption("axis.x.cex")),
       getOption("axis.cex"), getOption("axis.x.cex"))
-  if (text.cex > 0.99) text.cex <- .83 * text.cex
+  if (text.cex > 0.99) text.cex <- .95 * text.cex
 
   ll <- legend(0,0, legend=colnms, cex=.7, pt.cex=0.9,
                horiz=TRUE, plot=FALSE)  # get coordinates
@@ -27,8 +28,9 @@ function(colnms, horiz, color, fill, shape, col.bg, usr, lab.cex=0.8) {
     xleft <- usr[1] + axis.horiz/2 - lgnd.hhalf
 
     legend(xleft, ytop, legend=colnms, horiz=TRUE, box.lwd=.5, 
-           box.col="gray30", cex=text.cex, pt.cex=1.2, pt.bg=fill, bg=col.bg,
-           col=color, pch=shape, text.col=the.clr) # display legend
+           box.col="transparent", cex=text.cex, pt.cex=pt.size,
+           pt.bg=fill, bg=col.bg,
+           col=color, pch=shape, text.col=the.clr, title=legend.title) 
   }
 
   else {  # vertical
@@ -50,9 +52,10 @@ function(colnms, horiz, color, fill, shape, col.bg, usr, lab.cex=0.8) {
     yi <- ifelse (options("device") == "RStudioGD", 1.4, 1)
 
     legend(xleft, ytop, legend=colnms, horiz=FALSE, box.lwd=.5, 
-           box.col="gray30", cex=text.cex, pt.cex=1.2, pt.bg=fill, bg=col.bg,
+           box.col="transparent", cex=text.cex, pt.cex=pt.size,
+           pt.bg=fill, bg=col.bg,
            col=color, pch=shape, text.col=the.clr,
-           x.intersp=xi, y.intersp=yi)  # display legend
+           x.intersp=xi, y.intersp=yi, title=legend.title)  # display legend
   }
 
   par(xpd=FALSE)  # cancel drawing outside of plot region (need for RStudio)
