@@ -1,9 +1,9 @@
 simMeans <- 
 function(ns, n, mu=0, sigma=1, ylim.bound=NULL, 
          show.title=TRUE, show.data=TRUE, max.data=10, 
-         color.grid="grey90", pause=FALSE,
+         grid="grey90", pause=FALSE,
          sort=NULL, set.mu=FALSE, digits.d=2,
-         main=NULL, pdf.file=NULL, pdf.width=5, pdf.height=5, ...) {
+         main=NULL, pdf.file=NULL, width=5, height=5, ...) {
 
 
   if (missing(ns)) {
@@ -85,7 +85,7 @@ function(ns, n, mu=0, sigma=1, ylim.bound=NULL,
   # plot 
 
   # set up graphics system
-  .opendev(pdf.file, pdf.width, pdf.height)
+  .opendev(pdf.file, width, height)
 
   orig.params <- par(no.readonly=TRUE)
   par(mar=c(3,3,1.75,2), mgp=c(1.75,.5,0))
@@ -100,8 +100,8 @@ function(ns, n, mu=0, sigma=1, ylim.bound=NULL,
   # grid lines
   vx <- pretty(c(usr[1],usr[2]))
   vy <- pretty(c(usr[3],usr[4]))
-  abline(v=seq(vx[1],vx[length(vx)],vx[2]-vx[1]), col=color.grid, lwd=.5)
-  abline(h=seq(vy[1],vy[length(vy)],vy[2]-vy[1]), col=color.grid, lwd=.5)
+  abline(v=seq(vx[1],vx[length(vx)],vx[2]-vx[1]), col=grid, lwd=.5)
+  abline(h=seq(vy[1],vy[length(vy)],vy[2]-vy[1]), col=grid, lwd=.5)
 
   if (!set.mu && !pause) {
     if (show.title) title(main = bquote(paste(mu, "=", .(mu), "  ", sigma, "=", .(sigma), 
